<?php
/**
 * PHP Wrapper for accessing data in the VinAudit.com API.
 * By: VinAudit.com LLC (support@vinaudit.com)
 *
 * Documentation: http://www.vinaudit.com/api-documentation
 *
 * Please update $API_USER, $API_PASS, $API_KEY, and $API_MODE below
 *
 * Example: Query Test VIN 1GNSKHE34BR150574 (with $API_MODE = 'test')
 * 
 * $vin = '1GNSKHE34BR150574';
 * $queryResult = VinAudit::query($vin);
 * if ($queryResult->success) {
 *    $reportResult = VinAudit::pullReport($queryResult->id, $vin);
 *    print_r($reportResult);
 * }
 *
 */
class VinAudit {
  private static $API_USER = 'YOUR_API_USERNAME';
  private static $API_PASS = 'YOUR_API_PASSWORD';
  private static $API_KEY = 'YOUR_API_KEY';
  private static $API_MODE = 'test';  // change from 'test' to 'prod' to run non-test VINs

  public static function query($vin) {
    return self::request('query.php', array(
      'vin' => $vin,
      'mode' => self::$API_MODE,
      'key' => self::$API_KEY
      ));
  }
  
  public static function pullReport($id, $vin) {
    return self::request('pullreport.php', array(
      'id' => $id,
      'vin' => $vin,
      'user' => self::$API_USER,
      'pass' => self::$API_PASS,
      'mode' => self::$API_MODE,
      'key' => self::$API_KEY
      ));
  }
  
  public static function saveReportPdf($id, $vin, $fileName) {
    return self::download('pullreport.php', array(
      'id' => $id,
      'vin' => $vin,
      'pdf' => 1,
      'user' => self::$API_USER,
      'pass' => self::$API_PASS,
      'mode' => self::$API_MODE,
      'key' => self::$API_KEY
      ), $fileName);
  }
  
  public static function request($api, $params, $maxTries = 3) {
    $url = 'https://api.vinaudit.com/' . $api;
    $params['format'] = 'json';
    $curl = curl_init();
    curl_setopt($curl, CURLOPT_URL, $url);
    curl_setopt($curl, CURLOPT_POST, TRUE);
    curl_setopt($curl, CURLOPT_POSTFIELDS, $params);
    curl_setopt($curl, CURLOPT_RETURNTRANSFER, TRUE);
    curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, FALSE);
    curl_setopt($curl, CURLOPT_SSL_VERIFYHOST, FALSE);
    curl_setopt($curl, CURLOPT_TIMEOUT, 60);
    $content = curl_exec($curl);
    curl_close($curl);
    
    $obj = json_decode($content);
    if ($obj) {
      return $obj;
    } else if ($maxTries > 0) {
      return self::request($api, $params, $maxTries - 1);
    } else {
      return null;
    }
  }
  
  public static function download($api, $params, $fileName) {
    $url = 'https://api.vinaudit.com/' . $api;
    $params['format'] = 'json';
    $curl = curl_init();
    curl_setopt($curl, CURLOPT_URL, $url);
    curl_setopt($curl, CURLOPT_POST, TRUE);
    curl_setopt($curl, CURLOPT_POSTFIELDS, $params);
    curl_setopt($curl, CURLOPT_RETURNTRANSFER, TRUE);
    curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, FALSE);
    curl_setopt($curl, CURLOPT_SSL_VERIFYHOST, FALSE);
    curl_setopt($curl, CURLOPT_TIMEOUT, 100);
    $content = curl_exec($curl);
    $contentType = curl_getinfo($curl, CURLINFO_CONTENT_TYPE);
    curl_close($curl);
    
    if ($contentType == 'application/pdf') {
      file_put_contents($fileName, $content);
      return true;
    } else {
      // print $content;
    }
    return false;
  }
}
